import { DependencyContainer } from "tsyringe";

import { ConfigServer } from "@spt-aki/servers/ConfigServer";
import { ConfigTypes } from "@spt-aki/models/enums/ConfigTypes";
import { DatabaseServer } from "@spt-aki/servers/DatabaseServer";
import { IPostDBLoadMod } from "@spt-aki/models/external/IPostDBLoadMod";


class KHCM implements IPostDBLoadMod {
    private modConfig = require("../config/config.json");
    private keyLocations = require("../config/keys.json");

    postDBLoad(container: DependencyContainer): void {
        const logger = container.resolve<ILogger>("WinstonLogger");
        const databaseServer = container.resolve<DatabaseServer>("DatabaseServer");
        const configServer = container.resolve<ConfigServer>("ConfigServer");

        const tables = databaseServer.getTables();
        const handbook = tables.templates.handbook.Items;
        const items = tables.templates.items;
        const quests = JSON.stringify(tables.templates.quests).trim();
        const hideout = JSON.stringify(tables.hideout.areas).trim();
        const production = JSON.stringify(tables.hideout.production).trim();

		//const locales = tables["locales"]["global"][this.modConfig.language]["templates"];
		const locales = tables["locales"]["global"][this.modConfig.language];
        const prices = tables["templates"]["prices"];

		let cntall = 0;
		let cntval = 0;
		for (let HId in handbook) {
			let id = handbook[HId].Id;

			let	priceH = handbook[HId].Price;
			let priceP = prices[id];

			if (priceH == null) {
				priceH = 999999999;
			}
			if (priceP == null) {
				priceP = 999999999;
			}
			
			let price = Math.min(priceH,priceP);
			if (price == 999999999) {
				price = 0;
			}
			
			if (this.modConfig.showPrice) {
				let priceinfo = price.toLocaleString();
				if (this.modConfig.showFleaPrice) {
					if ((priceP != 999999999) && Math.abs(priceP-priceH)>100000) {
						priceinfo += "/" + priceP.toLocaleString();
					}
				}
				
				locales[id + " Description"] += " ₽" + priceinfo;
			}
			
			let ammostats = "";
			if (this.modConfig.showPrefix) {
				let isItem = (items[id]._type=="Item");
				let isCase = (items[id]._name.indexOf("_rig_")!=-1) || (items[id]._name.indexOf("backpack")!=-1) || (items[id]._name.indexOf("container")!=-1);
				let isWeapon = items[id]._name.substr(0,7)=="weapon_";
				let isAmmo = items[id]._parent == "5485a8684bdc2da71d8b4567";
				let isKey = (items[id]._parent == "5c99f98d86f7745c314214b3") || (items[id]._parent == "5c164d2286f774194c5e69fa");
				//if (id=="59fb023c86f7746d0d4b423c") {logger.info(items[id]._name + ", " + price)}
				if (isItem && !isCase && !isWeapon) {
					let size = items[id]._props.Width * items[id]._props.Height;
					let cellprice = price / size;
					if (cellprice > this.modConfig.minCellValue) {
						//locales[id].ShortName = this.modConfig.prefix + locales[id].ShortName;
						locales[id + " ShortName"] = this.modConfig.prefix + locales[id + " ShortName"];
						cntval++;
					}
					if (isAmmo) {
						ammostats = "Dam: " + items[id]._props.ArmorDamage + "/" + items[id]._props.Damage + ", Pen: " + items[id]._props.PenetrationPower
						locales[id + " Description"] += " [" + ammostats + "]";
					}
					if (isKey) {
						if (this.keyLocations[id]!=null) {
							locales[id + " Description"] += " [" + this.keyLocations[id] + "]";
							//logger.info(this.keyLocations[id]);
						}
					}
				} 
			}
			
			if (this.modConfig.showUsage) {
				let isQuestItem = quests.indexOf("target\":[\""+id)!=-1;
				let isHideoutItem = hideout.indexOf("templateId\":\""+id)!=-1;
				let isProductionItem = production.indexOf("templateId\":\""+id)!=-1;
				if (isQuestItem || isHideoutItem || isProductionItem) {
					var usedfor = "Used for: ";
					if (isQuestItem) {usedfor += "Quests, "};
					if (isHideoutItem && isProductionItem) {
						usedfor += "Hideout construction & production, "
					} else {
						if (isHideoutItem) {usedfor += "Hideout construction, "};
						if (isProductionItem) {usedfor += "Hideout production, "};
					}
					//locales[id].Description += "\n" + usedfor.substr(0,usedfor.length-2);
					locales[id + " Description"] += "\n" + usedfor.substr(0,usedfor.length-2);
				}
			}
			cntall++;
		}
		
		let info = "Item Info loaded. "
		if (this.modConfig.showPrice) {info += "Prices added, "};
		if (this.modConfig.showPrefix) {info += "Prefix added (" + cntval + " of " + cntall + " items over ₽" + this.modConfig.minCellValue.toLocaleString() + " per cell; " + Math.round(cntval*100/cntall) + "%), "};
		if (this.modConfig.showUsage) {info += "Usage added, "};
		info = info.substr(0,info.length-2) + ".";

		logger.info(info);

    }

}

    
module.exports = { mod: new KHCM() }